==> kollavarsham-1.9.2.tar.gz: kollavarsham-1.9.2/README.md <==
# [kollavarsham](http://kollavarsham.org/)

[![Build Status](https://img.shields.io/travis/kollavarsham/kollavarsham-js.svg)](https://travis-ci.org/kollavarsham/kollavarsham-js) [![Dependency Status](https://img.shields.io/david/kollavarsham/kollavarsham-js.svg)](https://david-dm.org/kollavarsham/kollavarsham-js) [![Dev-Dependency Status](https://img.shields.io/david/dev/kollavarsham/kollavarsham-js.svg)](https://david-dm.org/kollavarsham/kollavarsham-js#info=devDependencies&view=table) [![Coverage Status](https://coveralls.io/repos/github/kollavarsham/kollavarsham-js/badge.svg?branch=master)](https://coveralls.io/github/kollavarsham/kollavarsham-js?branch=master)

> Convert Gregorian date to Kollavarsham date and vice versa

## Install

### TypeScript/JavaScript/Node.js [![NPM version](https://badge.fury.io/js/kollavarsham.svg)](https://badge.fury.io/js/kollavarsham)

```sh
$ npm install kollavarsham
```

### Python [![PyPI version](https://badge.fury.io/py/kollavarsham.svg)](https://badge.fury.io/py/kollavarsham)

```sh
$ pip install kollavarsham
```

### C#/dotnet [![NuGet version](https://badge.fury.io/nu/KollavarshamOrg.Converter.svg)](https://badge.fury.io/nu/KollavarshamOrg.Converter)

```sh
$ dotnet add package KollavarshamOrg.Converter
```

## Usage

### TypeScript/JavaScript/Node.js

```js
import { Kollavarsham } from 'kollavarsham';

const options = {
  system: 'SuryaSiddhanta',
  latitude: 10,
  longitude: 76.2
};

const kollavarsham = new Kollavarsham(options);

const today = kollavarsham.fromGregorianDate(new Date());

console.log(today.year, today.mlMasaName, today.date, `(${today.mlNaksatraName})`);
```

### Python

```python
import datetime
import pytz
import kollavarsham

now = pytz.utc.localize(datetime.datetime.utcnow())
kv = kollavarsham.Kollavarsham(latitude=10, longitude=76.2, system="SuryaSiddhanta")

today = kv.from_gregorian_date(date=now)
print(today.year, today.ml_masa_name, today.date, '(' + today.naksatra.ml_malayalam + ')')
```

### C#/dotnet

```csharp
using System;
using KollavarshamOrg;

namespace Test
{
    class Program
    {
        static void Main(string[] args)
        {
            var settings = new Settings {
                Latitude = 10,
                Longitude = 76.2,
                System = "SuryaSiddhanta"
            };
            var kv = new Kollavarsham(settings);
            var today = kv.FromGregorianDate(DateTime.Now);
            Console.WriteLine($"{today.Year.ToString()} {today.MlMasaName} {today.Date.ToString()} ({today.MlNaksatraName})");
        }
    }
}
```

## Documentation

### TypeScript/JavaScript/Node.js

Check out the [Kollavarsham class](https://kollavarsham.org/kollavarsham-js/module-kollavarsham.Kollavarsham.html) within the API documentation as this is the entry point into the library.

## Release History

Check out the history at [GitHub Releases](https://github.com/kollavarsham/kollavarsham-js/releases)

## License

Copyright (c) 2014-2020 The Kollavarsham Team. Licensed under the [MIT license](http://kollavarsham.org/LICENSE.txt).

==> kollavarsham-2.0.0.tar.gz: kollavarsham-2.0.0/README.md <==
# [kollavarsham](http://kollavarsham.org/)

[![Build Status](https://img.shields.io/travis/kollavarsham/kollavarsham-js.svg)](https://travis-ci.org/kollavarsham/kollavarsham-js) [![Dependency Status](https://img.shields.io/david/kollavarsham/kollavarsham-js.svg)](https://david-dm.org/kollavarsham/kollavarsham-js) [![Dev-Dependency Status](https://img.shields.io/david/dev/kollavarsham/kollavarsham-js.svg)](https://david-dm.org/kollavarsham/kollavarsham-js#info=devDependencies&view=table) [![Coverage Status](https://coveralls.io/repos/github/kollavarsham/kollavarsham-js/badge.svg?branch=master)](https://coveralls.io/github/kollavarsham/kollavarsham-js?branch=master)

> Convert Gregorian date to Kollavarsham date and vice versa

## Install

### TypeScript/JavaScript/Node.js [![NPM version](https://img.shields.io/npm/v/kollavarsham)](https://www.npmjs.com/package/kollavarsham)

```sh
$ npm install kollavarsham
```

### Python [![PyPI version](https://img.shields.io/pypi/v/kollavarsham)](https://pypi.org/project/kollavarsham/)

```sh
$ pip install kollavarsham
```

### Java [![Maven version](https://img.shields.io/maven-central/v/org.kollavarsham.converter/kollavarsham-converter)](https://search.maven.org/artifact/org.kollavarsham.converter/kollavarsham-converter)

```xml
<dependency>
  <groupId>org.kollavarsham.converter</groupId>
  <artifactId>kollavarsham-converter</artifactId>
  <version>1.9.2</version>
</dependency>
```

### C#/dotnet [![NuGet version](https://img.shields.io/nuget/v/KollavarshamOrg.Converter)](https://www.nuget.org/packages/KollavarshamOrg.Converter)

```sh
$ dotnet add package KollavarshamOrg.Converter
```

## Usage

### TypeScript/JavaScript/Node.js

```js
import { Kollavarsham } from 'kollavarsham';

const options = {
  system: 'SuryaSiddhanta',
  latitude: 10,
  longitude: 76.2
};

const kollavarsham = new Kollavarsham(options);

const today = kollavarsham.fromGregorianDate(new Date());

console.log(today.year, today.mlMasaName, today.date, `(${today.mlNaksatraName})`);
```

### Python

```python
import datetime
import pytz
import kollavarsham

now = pytz.utc.localize(datetime.datetime.utcnow())
kv = kollavarsham.Kollavarsham(latitude=10, longitude=76.2, system="SuryaSiddhanta")

today = kv.from_gregorian_date(date=now)
print(today.year, today.ml_masa_name, today.date, '(' + today.naksatra.ml_malayalam + ')')
```

### Java

```java
package org.kollavarsham.tester;

import java.time.Instant;

import org.kollavarsham.converter.Kollavarsham;
import org.kollavarsham.converter.KollavarshamDate;
import org.kollavarsham.converter.Settings;
import org.kollavarsham.converter.Settings.Builder;

public class App {
    public static void main( final String[] args) {
        final Settings settings = new Builder().latitude(10).longitude(76.2).system("SuryaSiddhanta").build();
        final Kollavarsham kv = new Kollavarsham(settings);
        final KollavarshamDate today = kv.fromGregorianDate(Instant.now());
        System.out.println( today.getYear() + today.getMlMasaName() + today.getDate() + '(' + today.getMlNaksatraName() + ')' );
    }
}
```

### C#/dotnet

```csharp
using System;

namespace KollavarshamOrg.Tester
{
    class Program
    {
        static void Main(string[] args)
        {
            var settings = new Settings {
                Latitude = 10,
                Longitude = 76.2,
                System = "SuryaSiddhanta"
            };
            var kv = new Kollavarsham(settings);
            var today = kv.FromGregorianDate(DateTime.Now);
            Console.WriteLine($"{today.Year.ToString()} {today.MlMasaName} {today.Date.ToString()} ({today.MlNaksatraName})");
        }
    }
}
```

## Documentation

### TypeScript/JavaScript/Node.js

Check out the [Kollavarsham class](https://kollavarsham.org/kollavarsham-js/module-kollavarsham.Kollavarsham.html) within the API documentation as this is the entry point into the library.

## Release History

Check out the history at [GitHub Releases](https://github.com/kollavarsham/kollavarsham-js/releases)

## License

Copyright (c) 2014-2020 The Kollavarsham Team. Licensed under the [MIT license](http://kollavarsham.org/LICENSE.txt).
